@@ -16,6 +16,7 @@ class GraphAPI(object):
         :param oauth_token: A string describing an OAuth access token.
         """
         self.oauth_token = oauth_token
+        self.session = requests.session()
 
     def get(self, path='', page=False, **options):
         """
@@ -147,7 +148,7 @@ class GraphAPI(object):
             if method in ['GET', 'DELETE']:
 
                 try:
-                    response = requests.request(method, url, params=data, allow_redirects=True)
+                    response = self.session.request(method, url, params=data, allow_redirects=True)
                 except requests.RequestException as exception:
                     raise self.HTTPError(exception.message)
 
@@ -163,7 +164,7 @@ class GraphAPI(object):
                     data.pop(key)
 
                 try:
-                    response = requests.request(method, url, data=data, files=files)
+                    response = self.session.request(method, url, data=data, files=files)
                 except requests.RequestException as exception:
                     raise self.HTTPError(exception.message)
 
@@ -230,11 +231,16 @@ class GraphAPI(object):
         # We'll handle this discrepancy as gracefully as we can by implementing logic to deal with this behavior
         # in the high-level access functions (get, post, delete etc.).
         if type(data) is dict:
-
             if 'error' in data:
                 error = data['error']
+                error_type = error.get('type')
 
-                raise self.FacebookError(
+                if error_type == "OAuthException":
+                    exception = self.OAuthError
+                else:
+                    exception = self.FacebookError
+
+                raise exception(
                     error.get('message'),
                     error.get('code', None)
                 )
@@ -254,5 +260,8 @@ class GraphAPI(object):
 
             self.code = code
 
+    class OAuthError(FacebookError):
+        """Exception for errors specifically related to OAuth."""
+
     class HTTPError(FacepyError):
         """Exception for transport errors."""
